@@ -16,7 +16,8 @@ sub ORIGINAL;
 
 sub arguments {
   my ($self, $occurance) = @_;
-  return $self->{arguments}[$occurance // 0];
+  $occurance = 0 unless defined $occurance;
+  return $self->{arguments}[$occurance];
 }
 
 sub called { scalar @{$_[0]{arguments}} }
